@@ -21,7 +21,9 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-from PyQt4.QtGui import QWidget
+# from PyQt4.QtGui import QWidget
+from ffado.import_pyqt import *
+
 from mixer_nodeviceui import Ui_NoDeviceMixerUI
 
 class NoDevice(QWidget, Ui_NoDeviceMixerUI):
